/* useradd */

/* Preliminary UserAdd script for Samba for OS/2 */

UnixRoot = value("UNIXROOT",,'OS2ENVIRONMENT')
masterpasswd = UnixRoot'\etc\master.passwd'

/* Minimum UID that a user can obtain */
MinUID = 100

/* Structure of master.passwd file:
   Username:password:User-ID(UID):Group-ID(GID):Login-Class:Change pw in x seconds:Deactivate in x seconds:GECOS:HOME:SHELL
 */

/* Read complete master.passwd */
I = 0
do until lines(masterpasswd) = 0
    userline = strip(linein(masterpasswd))
    
    /* Skip comments */
    if left(userline,1) = "#" then iterate
    
    /* parse fields into stem variables */
    I = I + 1
	parse var userline username.I':'password.I':'uid.I':'gid.I':'LoginClass.I':'pwchange.I':'deact.I':'gecos.I':'home.I':'shell.I
	
    /* auxilary stem to determine next free UID, SUID = sorted UID */
    suid.I = right('00000'uid.I,5)
end

/* set "stem roots" properly */
suid.0      = I
username.0  = I
password.0  = I
uid.0       = I
gid.0       = I
loginclass.0= I
pwchange.0  = I
deact.0     = I
gecos.0     = I
home.0      = I
shell.0     = I

/* sort auxilary SUID (=sorted UID) stem */
ok = SysStemSort("SUID.","A")

/* determine next free UID */
u = MinUID + 1
do I = 1 to suid.0
    if suid.i <= MinUID then iterate
    if strip(suid.i,'L','0') = U then do
        U = U + 1
        iterate
    end
    leave
end
NextFreeUID = U

/* Add new user to the stems */
I = uid.0
I = I + 1
uid.0 = I

/* set new values */
username.I   = arg(1)              /* we get that from Samba */
password.I   = '*'                 /* dummy value */
uid.I        = NextFreeUID           
gid.I        = NextFreeUID         /* Should be group ID (GID) !!! */
loginclass.I = ''                  /* dummy value */
pwchange.I   = '0'                 /* dummy value */
deact.I      = '0'                 /* dummy value */
gecos.I      = arg(1)              /* not really appropriate, but better than a dummy value */
home.I       = '/nonexistent'      /* dummy value */
shell.I      = '/usr/sbin/nologin' /* dummy value */

/* write new user */
call lineout masterpasswd, username.I':'password.I':'uid.I':'gid.I':'loginclass.I':'pwchange.I':'deact.I':'gecos.I':'home.I':'shell.I
ok = stream(masterpasswd,'c','close')

/* delete old .db and db.tmp files */
ok = SysFileDelete(UnixRoot'\etc\pwd.db.tmp')
ok = SysFileDelete(UnixRoot'\etc\pwd.db')
ok = SysFileDelete(UnixRoot'\etc\spwd.db.tmp')
ok = SysFileDelete(UnixRoot'\etc\spwd.db')

/* Create new password db */
UnixRoot'\usr\sbin\pwd_mkdb.exe 'UnixRoot'\etc\master.passwd'
